FloatingSnackBarType enum

The semantic style of a floating snackbar.

Each type maps to a default color and a default leading icon defined on the active FloatingSnackBarTheme.

Inheritance
Available extensions

Values

normal → const FloatingSnackBarType

A neutral message with no semantic color (uses the default background).

success → const FloatingSnackBarType

A positive/confirmation message (green by default).

error → const FloatingSnackBarType

An error/failure message (red by default).

warning → const FloatingSnackBarType

A cautionary message (amber by default).

info → const FloatingSnackBarType

An informational message (blue by default).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FloatingSnackBarType>
A constant List of the values in this enum, in order of their declaration.