FloatingSnackBarAction class
A tappable action rendered on the trailing edge of a floating snackbar.
- Annotations
Constructors
- FloatingSnackBarAction({required String label, required VoidCallback onPressed, Color? textColor, bool dismissOnPressed = true})
-
Creates an action with a
labeland anonPressedcallback.const
Properties
- dismissOnPressed → bool
-
Whether tapping the action also dismisses the snackbar. Defaults to true.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
The button label.
final
- onPressed → VoidCallback
-
Invoked when the action is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color?
-
Optional color for the action label (defaults to the snackbar text color).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited